/************************************************************************************************

 Author        : ADI - Apps           www.analog.com

 Date          : July 2009

 File          : Timer.c

 Hardware      : ADuC7122

 Description   : The program shows how to configure Timer0 in periodic mode with an interrupt source.
*************************************************************************************************/
// Bit Definitions
#define BIT0  0x01
#define BIT1  0x02
#define BIT2  0x04
#define BIT3  0x08
#define BIT4  0x10
#define BIT5  0x20
#define BIT6  0x40
#define BIT7  0x80
#define BIT8  0x100
#define BIT9  0x200
#define BIT10 0x400
#define BIT11 0x800
#define BIT12 0x1000
#define BIT13 0x2000
#define BIT14 0x4000
#define BIT15 0x8000
#define BIT17 0x20000
#define BIT19 0x80000
#define BIT22 0x400000
#define BIT23 0x800000
#define BIT28 0x4000000
#define BIT30 0x40000000
#define BIT31 0x80000000
#define BIT22 0x400000

#include <ADuC7122.h>

unsigned char ucToggleRate = 0;
unsigned int uiTest = 0; 

int main(void)
{
	POWKEY1 = 0x01;		    // Configure CPU Clock for 41.78MHz, CD=0
 	POWCON = BIT1;
 	POWKEY2 = 0xF4;
        
	GP1DAT  = BIT31;		// Configure P1.7 as an output 
	
	// Initilize Timer 0 in Periodic mode with timeout period of 1 Second
	T0LD  = 0x8000;			// 32768 clock ticks
	T0CON = BIT6 + BIT7 ;	// Periodic mode, enable timer, 32768hz clock/1
	IRQCONE = BIT1;			// Rising edge
    IRQEN = BIT2 + BIT19;			// Enable Timer 0 IRQ

	while(1)
	{ 	
	}
}

void IRQ_Handler(void)  __irq  
{
    unsigned long IRQSTATUS = 0;

	IRQSTATUS = IRQSTA;	   			// Read off IRQSTA register

	if ((IRQSTATUS & BIT2) == BIT2)	//Timer 0 interrupt source
	{
		 GP1DAT ^= BIT23;			// Toggle LED on Evaluation board (P1.7)
		 T0CLRI = 0x55;				// Clear the currently active Timer0 Irq
	}
		if ((IRQSTATUS & BIT19) == BIT19)	//External Interrupt0 source
	{
		 ucToggleRate++;
		 IRQCLRE = BIT19;			   // Clear External Interrupt 0

		 if (ucToggleRate == 4)
		 	ucToggleRate = 0;
		 switch (ucToggleRate)
		 {
		  	case 0:
			{
				T0LD  = 0x8000;	// 1 second toggle rate
			 	break;
			}
			case 1:
			{
				T0LD  = 0x4000;	// 1/2 second toggle rate
			 	break;
			}
			case 2:
			{
				T0LD  = 0x2000;	// 1/4 second toggle rate
			 	break;
			}
		 } 
	}
}
